import random

def choisit(liste: list):
    """Choisit un objet dans une liste."""
    return random.choice(liste)
def choisitEntre(nombre1: int, nombre2: int):
    """Choisit un nombre entier entre deux certain nombres."""
    return random.randint(nombre1, nombre2)


from pyfrench import couleur, terminal, logique, maths

Vrai = True
Faux = False

def afficher(texte: str):
    """Écrit du texte dans le terminal."""
    return print(str(texte) + couleur.FIN)
def demander(question: str, nom: str = None):
    """Écrit du texte posée en forme de question."""
    if nom == None:
        nom = 'Vous'
    return input('{}\n{}: '.format(question, nom) + couleur.FIN)

# Condition
def si(valeur: bool):
    """Retourne une valeur booléen."""
    return valeur
def replacePar(texte: str, caractère1: str, caractère2: str):
    """Remplace un caractère par un autre dans un texte."""
    return texte.replace(caractère1, caractère2)

def commencePar(texte: str, mot: str):
    """Retourne une valeur boolén si un texte commence par un certain mot."""
    return texte.startswith(mot)
def finitPar(texte: str, mot: str):
    """Retourne une valeur booléen si un texte finit par un certain mot."""
    return texte.endswith(mot)

# Fichier
def ouvrir(fichier: str):
    """Ouvre des fichiers"""
    return open(file=fichier)

# Lien
def google(recherche: str):
    """Effectue une recherche Google"""
    resutlat = recherche.replace("+", "%2B")
    return f'https://www.google.com/search?q={resutlat.replace(" ", "+")}'
def youtube(recherche: str):
    """Effectue une recherche YouTube"""
    return f'https://www.youtube.com/watch?v={recherche}'


VIOLET = '\033[95m'
CYAN = '\033[96m'
CYAN_FONCÉ = '\033[36m'
BLEU = '\033[94m'
VERT = '\033[92m'
JAUNE = '\033[93m'
ROUGE = '\033[91m'
BLANC = '\033[37m'
NOIR = '\033[30m'
MAGENTA = '\033[35m'
GRAS = '\033[1m'
DIM = '\033[2m'
NORMAL = '\033[22m'
SOULIGNE = '\033[4m'
FIN = '\033[0m'
def depuis_rgb(rouge: int, vert: int, bleu: int):
    """Permet d'avoir une couleur d'après une valeur RGB."""
    if rouge >= 256:
        return print('\033[38;2;235;162;52mATTENTION: Utilisez une valeur de couleur RGB en dessous de 255.' + FIN)
    if vert >= 256:
        return print('\033[38;2;235;162;52mATTENTION: Utilisez une valeur de couleur RGB en dessous de 255.' + FIN)
    if bleu >= 256:
        return print('\033[38;2;235;162;52mATTENTION: Utilisez une valeur de couleur RGB en dessous de 255.' + FIN)
    return "\033[38;2;{};{};{}m".format(rouge, vert, bleu)
def depuis_hex(couleur: str):
    """Permet d'avoir une couleur d'après une valeur HEX."""
    h = couleur.lstrip('#')
    rgb = tuple(int(h[i:i+2], 16) for i in (0, 2, 4))
    rgb_format1 = str(rgb).replace(",", ";")
    rgb_format2 = rgb_format1.replace("(", "")
    rgb_format3 = rgb_format2.replace(")", "")
    rgb_format4 = rgb_format3.replace(" ", "")
    return '\033[38;2;{}m'.format(rgb_format4)


from os import *
from pyfrench import couleur

def write(commande: str):
    """Effectue une commande  dans un terminal."""
    print(couleur.GRAS + couleur.VERT + "[pyfrench]" + couleur.FIN + couleur.GRAS + " -> {}".format(commande) + couleur.FIN)
    return system(commande)


def égale(valeur1: int, valeur2: int):
    """Retourne une valeur booléen si les deux valeurs sont égaux."""
    if valeur1 == valeur2:
        return True
    else:
        return False
def différentDe(valeur1: int, valeur2: int):
    """Retourne une valeur booléen si les deux valeurs sont différentes."""
    if valeur1 != valeur2:
        return True
    else:
        return False
def plusGrand(valeur1: int, valeur2: int):
    """Retourne une valeur booléen si la première valeur est plus grande que la deuxième."""
    if valeur1 > valeur2:
        return True
    else:
        return False
def plusPetit(valeur1: int, valeur2: int):
    """Retourne une valeur booléen si la première valeur est plus petite que la deuxième."""
    if valeur1 < valeur2:
        return True
    else:
        return False 
def égalePlusGrand(valeur1: int, valeur2: int):
    """Retourne une valeur booléen si la première valeur est égale ou plus grande que la deuxième."""
    if valeur1 >= valeur2:
        return True
    else:
        return False
def égalePlusPetit(valeur1: int, valeur2: int):
    """Retourne une valeur booléen si la première valeur est égale ou plus petit que la deuxième."""
    if valeur1 <= valeur2:
        return True
    else:
        return False
def AND(A: int, B: int):
    """Porte logique AND"""
    return A & B
def NOT(A: int):
    """Porte logique NOT"""
    return ~A+2
def XOR(x: int, y: int):
    """Porte logique XOR"""
    return bool((x and not y) or (not x and y))
def NAND(A: int, B: int):
    """Porte logique NAND"""
    return NOT(AND(A, B))
def OR(A: int, B: int):
    """Porte logique OR"""
    return A | B
def NOR(A: int, B: int):
    """Porte logique NOR"""
    return NOT(OR(A, B))
def XNOR(A: int, B: int):
    """Porte logique XNOR"""
    return NOT(XOR(A, B))


from math import *

def calcul(calcul: str):
    """Effectue un calcul."""
    return print(int(eval(calcul)))
def nombreNonDuplique(liste: list):
    """Trouve le nombre non dupliqué dans une liste."""
    resultat = 0
    for e in liste:
        resultat ^= e
    return resultat
def num(nombre: str):
    """Convertit un nombre textuel en nombre entier."""
    return int(nombre)
def txt(nombre: int):
    """Convertit un nombre entier en nombre texutel."""
    return str(nombre)
pi = 3.1415926535897932384626433832795028841971693993751058209749445923078164062862089986280348253421170679


from setuptools import find_packages, setup

from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name='pyfrench',
    packages=find_packages(),
    version='0.3.0a',
    description='Une librairie qui traduit python en français',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Artic#6377',
    license='MIT',
    url='https://github.com/ArticOff/pyfrench',
    install_requires=[],
    setup_requires=['pytest-runner'], 
    tests_require=['pytest'], 
    test_suite='tests',
    author_email="artic.admisoffi@gmail.com",
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Natural Language :: French',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11'
    ]
)


from pyfrench import afficher, couleur

def erreur(erreur: str):
    """Fait un message d'erreur."""
    return afficher(couleur.depuis_rgb(255, 0, 0) + 'ERREUR: {}'.format(erreur) + couleur.FIN)
def attention(texte: str):
    """Fait un message de prévention."""
    return afficher(couleur.depuis_rgb(235, 192, 52) + 'ATTENTION: {}'.format(texte) + couleur.FIN)
def succes(texte: str):
    """Fait un message de succès."""
    return afficher(couleur.depuis_rgb(45, 166, 49) +  'SUCCÈS: {}'.format(texte) + couleur.FIN)
def conseil(texte: str):
    """Fait un message de conseil."""
    return afficher(couleur.depuis_rgb(80, 140, 212) + 'CONSEIL: {}'.format(texte) + couleur.FIN)